.. stistools documentation master file, created by
   Warren Hack on Mon Oct 1 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to stistool's documentation!
========================================
This package provides data processing tools for working with STIS data.


Contents:
 
.. toctree::
   :maxdepth: 2

   basic2d
   calstis
   sshift
   stisnoise
   mktrace
   evaldisp
   wavelen
   wx2d
   radialvel
   r_util
   gettable

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
